@@ -24,10 +24,12 @@ use Dancer::SharedData;
 use Dancer::Handler;
 use Dancer::ModuleLoader;
 
+use File::Spec;
+
 use base 'Exporter';
 
 $AUTHORITY = 'SUKRIA';
-$VERSION   = '1.1803';
+$VERSION   = '1.1804';
 @EXPORT    = qw(
   ajax
   any
@@ -158,7 +160,7 @@ sub load_app {
     for my $app (@_) {
         Dancer::Logger->core("loading application $app");
 
-        use lib path(dirname(abs_path($0)), 'lib');
+        use lib path( dirname( File::Spec->rel2abs($0) ), 'lib' );
 
         # we want to propagate loading errors, so don't use ModuleLoader here
         eval "use $app";
