@@ -23,7 +23,7 @@ sub init {
     };
 
     my $start_tag = $self->config->{start_tag} || '<%';
-    my $stop_tag  = $self->config->{stop_tag}  || '%>';
+    my $stop_tag  = $self->config->{stop_tag}  || $self->config->{end_tag} || '%>';
 
     # FIXME looks like if I set START/END tags to TT's defaults, it goes crazy
     # so I only change them if their value is different
@@ -59,18 +59,26 @@ Dancer::Template::TemplateToolkit - Template Toolkit wrapper for Dancer
 This class is an interface between Dancer's template engine abstraction layer
 and the L<Template> module.
 
-This template engine is recomended for production purproses, but depends on the
+This template engine is recomended for production purposes, but depends on the
 Template module.
 
-In order to use this engine, set the following setting as the following:
+In order to use this engine, use the template setting:
 
     template: template_toolkit
 
 This can be done in your config.yml file or directly in your app code with the
 B<set> keyword.
 
-Note that Dancer configures the Template::Toolkit engine to use <% %> brackets
-instead of its default [% %] brackets.
+Note that by default,  Dancer configures the Template::Toolkit engine to use 
+<% %> brackets instead of its default [% %] brackets.  This can be changed
+within your config file - for example:
+
+    template: template_toolkit
+    engines:
+        template_toolkit:
+            start_tag: '[%'
+            stop_tag: '%]'
+
 
 =head1 SEE ALSO
 
